@@ -39,5 +39,8 @@ def from_load(load):
 	del trans_data['customer_id']
 	trans_data['client_id'] = None
 	trans_data['equipment_class'] = None
+	trans_data['origin_pallets_required'] = load.origin_pallets_required
+	trans_data['destination_pallets_required'] = load.destination_pallets_required
+	trans_data['hazmat'] = load.hazmat
 	transaction = Transaction(**trans_data)
 	return transaction
