@@ -93,3 +93,5 @@ class Transaction:
     pieces: int = field(default=None)
     max_temperature: float = field(default=None)
     min_temperature: float = field(default=None)
+    origin_pallets_required: bool = field(default=False)
+    destination_pallets_required: bool = field(default=False)
